@@ -1,12 +1,11 @@
 from fastapi import Depends
 from fastapi.security import APIKeyHeader
 
-from deciphon_api.core.settings import get_settings
+from deciphon_api.core.settings import settings
 
 __all__ = ["auth_request"]
 
 
 def auth_request(token: str = Depends(APIKeyHeader(name="X-API-Key"))) -> bool:
-    settings = get_settings()
     authenticated = token == settings.api_key
     return authenticated
